import React from "react";
import { Card, CardHeader } from "@mui/material";
import { useState, useEffect } from "react";
import { useIOCSearch } from "../../../api/SwaggerApi";
import { IOCAsyncList } from "../../IOC/IOCAsyncList";
import { initRequestParams } from "../Helper";

export function UserIocList({ userName }) {
  const [iocs, getIocs, , loading] = useIOCSearch();
  const [iocList, setIocList] = useState([]);
  const rowsPerPage = [20, 50];

  const [lazyParams, setLazyParams] = useState({
    first: 0,
    rows: 20,
    page: 0
  });

  useEffect(() => {
    setIocList(iocs.iocList);
  }, [iocs, setIocList]);

  useEffect(() => {
    let requestParams = initRequestParams(lazyParams);

    requestParams.owner = userName;

    getIocs(requestParams);
  }, [getIocs, lazyParams, userName]);

  return (
    <Card>
      <CardHeader
        title={`IOCs registered by ${userName}`}
        titleTypographyProps={{
          variant: "h2",
          component: "h2"
        }}
      />
      <IOCAsyncList
        iocs={iocList}
        setIocs={setIocList}
        loading={loading}
        rowType="explore"
        lazyParams={lazyParams}
        setLazyParams={setLazyParams}
        totalCount={iocs.totalCount}
        rowsPerPage={rowsPerPage}
      />
    </Card>
  );
}
