import React from "react";
import { Card, CardHeader } from "@mui/material";
import { initRequestParams } from "../Helper";
import { useEffect, useState } from "react";
import { useOperationsSearch } from "../../../api/SwaggerApi";
import { JobAsyncList } from "../../Job/JobAsyncList";

export function UserOperationList({ userName }) {
  const [operations, getOperations, , loading] = useOperationsSearch();

  const [lazyParams, setLazyParams] = useState({
    first: 0,
    rows: 20,
    page: 0
  });

  const rowsPerPage = [20, 50];

  const [jobList, setJobList] = useState([]);

  useEffect(() => {
    let requestParams = initRequestParams(lazyParams);

    requestParams.user = userName;

    getOperations(requestParams);
  }, [getOperations, lazyParams, userName]);

  useEffect(() => {
    setJobList(operations.operationsList);
  }, [operations, setJobList]);

  return (
    <Card>
      <CardHeader
        title={`Operations by ${userName}`}
        titleTypographyProps={{
          variant: "h2",
          component: "h2"
        }}
      />
      <JobAsyncList
        jobs={jobList}
        setJobs={setJobList}
        loading={loading}
        totalCount={operations.totalCount}
        lazyParams={lazyParams}
        setLazyParams={setLazyParams}
        rowsPerPage={rowsPerPage}
      />
    </Card>
  );
}
