import React from "react";
import { styled } from "@mui/material/styles";
import { Paper, Typography, Box, Button, Link } from "@mui/material";
import { RootContainer } from "../../components/common/Container/RootContainer";
import { useRedirect } from "../../hooks/Redirect";

const PREFIX = "NotFound";

const classes = {
  paper: `${PREFIX}-paper`
};

const StyledRootContainer = styled(RootContainer)(({ theme }) => ({
  [`& .${classes.paper}`]: {
    maxWidth: "80%",
    padding: theme.spacing(4)
  }
}));

export default function NotFound({ message }) {
  const redirect = useRedirect();

  const goHome = () => {
    redirect("/home");
  };

  // if the not found page has recceived any parameters -> show that as content; otherwise show default message
  const content = message ? (
    <Box
      display="flex"
      justifyContent="center"
      paddingTop={1}
      paddingBottom={3}
    >
      <Typography variant="h4">{message}</Typography>
    </Box>
  ) : (
    <>
      <Box
        display="flex"
        justifyContent="center"
        paddingTop={1}
        paddingBottom={3}
      >
        <Typography variant="h4">{"Page not found"}</Typography>
      </Box>

      <Box
        display="flex"
        justifyContent="center"
        paddingBottom={3}
      >
        <Typography>
          {
            "The page you are looking for may have been moved, deleted, or possibly never existed."
          }
        </Typography>
      </Box>

      <Box
        display="flex"
        justifyContent="center"
        paddingBottom={3}
      >
        <Typography>
          Contact the &nbsp;
          {
            <Link
              href="https://jira.esss.lu.se/plugins/servlet/desk/portal/44?requestGroup=137"
              target="_blank"
              rel="noreferrer"
              underline="hover"
            >
              Service Desk
            </Link>
          }
          &nbsp; if you need support.
        </Typography>
      </Box>
    </>
  );

  return (
    <StyledRootContainer>
      <Paper className={classes.paper}>
        <Box
          display="flex"
          justifyContent="center"
        >
          <Typography variant="h3">404</Typography>
        </Box>
        {content}
        <Box
          display="flex"
          justifyContent="center"
        >
          <Button
            variant="contained"
            color="secondary"
            onClick={goHome}
          >
            Return to Home
          </Button>
        </Box>
      </Paper>
    </StyledRootContainer>
  );
}
