import React from "react";
import { CustomTable } from "../common/table/CustomTable";
import { RecordStatusIcon } from "./RecordIcons";
import { Grid } from "@mui/material";
import { useRedirect } from "../../hooks/Redirect";

const recordsColumns = [
  { id: "bulb", label: "Status", width: "5ch", textAlign: "center" },
  { id: "name", label: "Record", width: "15ch" },
  { id: "iocName", label: "IOC name", width: "15ch" },
  { id: "hostName", label: "Host", width: "15ch" }
];

const iocDetailsColumns = [
  { id: "bulb", label: "Status", width: "5ch", textAlign: "center" },
  { id: "name", label: "Record", width: "15ch" },
  { id: "iocVersion", label: "Version", width: "15ch" }
];

export function createRecordsRow(record) {
  return {
    id: record.name,
    bulb: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <RecordStatusIcon record={record} />
      </Grid>
    ),
    name: record.name,
    iocName: record.iocName,
    hostName: record.hostName
  };
}

export function createIocDetailsRow(record) {
  return {
    id: record.name,
    bulb: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <RecordStatusIcon record={record} />
      </Grid>
    ),
    name: record.name,
    iocVersion: record.iocVersion
  };
}

export function RecordTable({
  records,
  rowType = "records",
  lazyParams,
  setLazyParams,
  rowsPerPage,
  loading
}) {
  const tableTypeSpecifics = {
    records: [recordsColumns, createRecordsRow],
    iocDetails: [iocDetailsColumns, createIocDetailsRow]
  };

  const [columns, createRow] = tableTypeSpecifics[rowType];

  const redirect = useRedirect();

  const itemLink = (name) => `/records/${encodeURIComponent(name)}`;

  const onRowClicked = (id) => {
    redirect(itemLink(id));
  };

  return (
    <CustomTable
      columns={columns}
      rows={records.recordList.map((record) => createRow(record))}
      // Total count must be practically infinity for now (till total count can be retrieved from API)
      totalCount={
        records.listSize < records.limit
          ? records.listSize + records.limit * records.pageNumber
          : 1000000
      }
      lazyParams={lazyParams}
      setLazyParams={setLazyParams}
      rowsPerPage={rowsPerPage}
      loading={loading}
      paginatorTemplate="FirstPageLink PrevPageLink NextPageLink RowsPerPageDropdown"
      handleRowClick={onRowClicked}
    />
  );
}
