import React from "react";
import { SnackbarProvider } from "notistack";
import { Container, StyledEngineProvider } from "@mui/material";
import { ThemeProvider } from "@mui/material/styles";
import { theme } from "../style/Theme";
import { APIProvider } from "../api/SwaggerApi";
import { UserProvider } from "../api/UserProvider";
import { NotificationProvider } from "../components/common/notification/Notifications";
import NavigationMenu from "../components/navigation/NavigationMenu";
import { MemoryRouter } from "react-router-dom";

export function AppHarness({ children, initialHistory = ["/"] }) {
  return (
    <SnackbarProvider
      preventDuplicate
      maxSnack="5"
    >
      <StyledEngineProvider injectFirst>
        <ThemeProvider theme={theme}>
          <MemoryRouter initialEntries={initialHistory}>
            <APIProvider>
              <UserProvider>
                <NotificationProvider>
                  <NavigationMenu>
                    <Container>{children}</Container>
                  </NavigationMenu>
                </NotificationProvider>
              </UserProvider>
            </APIProvider>
          </MemoryRouter>
        </ThemeProvider>
      </StyledEngineProvider>
    </SnackbarProvider>
  );
}

export function RouterHarness({ children, initialHistory = ["/"] }) {
  return (
    <StyledEngineProvider injectFirst>
      <ThemeProvider theme={theme}>
        <MemoryRouter initialEntries={initialHistory}>{children}</MemoryRouter>
      </ThemeProvider>
    </StyledEngineProvider>
  );
}
