import React, { useCallback, useRef, useState } from "react";
import { JobDetailsView } from "./JobDetailsView";
import { LinearProgress } from "@mui/material";
import { useOperation, useJobById } from "../../api/SwaggerApi";
import { useSafePolling } from "../../hooks/Polling";
import NotFound from "../../components/navigation/NotFound";
import { onFetchEntityError } from "../../components/common/Helper";

const POLL_DEPLOYMENT_INTERVAL = 5000;
export function JobDetailsContainer({ id }) {
  const [notFoundError, setNotFoundError] = useState();

  const [operation, getOperation /* reset*/, , operationLoading] = useOperation(
    id,
    (m, s) => {
      // handle error code 404, and define custom message on the UI because BE sends back generic error message
      onFetchEntityError(m, s, setNotFoundError);
    }
  );
  const [job, getJobById, , /* reset*/ jobLoading] = useJobById();
  const firstTime = useRef(true);

  const jobFinished = job?.finished;

  const getOperationUntilFinished = useCallback(() => {
    if (!jobFinished) {
      getOperation();
    }
  }, [jobFinished, getOperation]);

  const getAwxJobUntilFinished = useCallback(() => {
    if (!jobFinished || firstTime.current) {
      if (operation?.awxJobId) {
        getJobById(operation.awxJobId);
        firstTime.current = false;
      }
    }
  }, [operation?.awxJobId, jobFinished, getJobById]);

  return (
    <>
      {notFoundError ? (
        <NotFound />
      ) : operation ? (
        <JobDetailsView
          operation={operation}
          job={job}
        />
      ) : (
        <LinearProgress color="primary" />
      )}
      <Watcher
        get={getOperationUntilFinished}
        loading={operationLoading}
      />
      {operation?.awxJobId && (
        <Watcher
          get={getAwxJobUntilFinished}
          loading={jobLoading}
        />
      )}
    </>
  );
}

function Watcher({ get, loading }) {
  useSafePolling(get, loading, POLL_DEPLOYMENT_INTERVAL);
  return null;
}
